package com.cours.spring.controller;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import com.cours.entities.MyModel;
import com.cours.spring.validators.MyModelValidator;

@Controller
@RequestMapping("/myPath")
public class MyController {

	
	@Autowired
	private MyModelValidator myModelValidator;
	
	// @RequestMapping("/myMethod1")
	// @RequestMapping(value = "/myMethod1", method = RequestMethod.POST)
	// @RequestMapping(value = "/myMethod1", params = {
	// "param1=valueParam1","param2=valueParam2" })
	// @RequestMapping(value = "/myMethod1", headers = "Accept=text/html")
	@GetMapping("/myMethod1")
	public String myMethod1(Model model) {
		model.addAttribute("myKey", "myValue");
		return "myPage";
	}

	@RequestMapping("/myMethod2")
	public String myMethod2(@RequestParam("myParam") String myParam, Model model) {
		model.addAttribute("myKey", myParam);
		return "myPage";
	}

	@RequestMapping("/myMethod3/{id}")
	public String myMethod3(@PathVariable("id") Long id, Model model) {
		model.addAttribute("myKey", id);
		return "myPage";
	}

	@RequestMapping("/myMethod4/{id}")
	// Melange de PathVariable et RequestParam
	public String myMethod4(@RequestParam("myParam") String myParam, @PathVariable("id") Long id, Model model) {
		model.addAttribute("myKey", "id=" + id + " et myParam=" + myParam);
		return "myPage";
	}

	@RequestMapping("/create")
	public String create(Model model) {
		MyModel myModel = new MyModel("myValue1","myValue2");
		model.addAttribute("myModel", myModel);
		return "myFormPage";
	}
	
	
	@RequestMapping(value = "/save", method = RequestMethod.POST)
	public String save(@Valid @ModelAttribute("myModel") MyModel myModel,BindingResult result,Model model) {
		System.out.println("myModel : " + myModel);
		myModelValidator.validate(myModel, result);
		if (result.hasErrors()) {
	        return "myFormPage";
	    }
		return "redirect:/";
	}
	
	@RequestMapping(value = "/saveV2", method = RequestMethod.POST)
	public String saveV2(@Valid @ModelAttribute("myModel") MyModel myModel,BindingResult result,Model model) {
		System.out.println("myModel : " + myModel);
		if (result.hasErrors()) {
			model.addAttribute("errorMessage", "DONNEES INCORECTS");
	        return "myFormPage";
	    }
		return "redirect:/";
	}
	
	@RequestMapping(value = "/saveV1", method = RequestMethod.POST)
	public String saveV1(@ModelAttribute("myModel") MyModel myModel) {
		System.out.println("myModel : " + myModel);
		return "redirect:/";
	}
}